pub struct ChangeSet {
pub entries: Vec<ChangeEntry>,
pub unmanaged_grants: Vec<UnmanagedGrantObservation>,
pub revokes_with_owner: Vec<RevokeWithOwnerObservation>,
}Expand description
An unordered set of ChangeEntry values.
Fields
entries: Vec<ChangeEntry>The change entries.
unmanaged_grants: Vec<UnmanagedGrantObservation>Grants observed in the live catalog whose grantee role is not tracked in the source catalog (lenient-policy observations).
Stage 11 lint rules read this to produce grants-to-unmanaged-role
warnings.
revokes_with_owner: Vec<RevokeWithOwnerObservation>REVOKE steps being emitted against the declared owner of the object.
Stage 11 lint rules read this to produce revoke-from-owner warnings.
Implementations