pub enum FunctionChange {
Create(Function),
Drop {
qname: QualifiedName,
args: NormalizedArgTypes,
},
CreateOrReplace(Function),
ReplaceWithCascade {
source: Function,
catalog: Function,
},
SetComment {
qname: QualifiedName,
args: NormalizedArgTypes,
comment: Option<String>,
},
}Expand description
A structural change to a single user-defined function.
Variants
Create(Function)
Create a new function.
Drop
Drop an existing function by qualified name and normalized arg types.
Fields

qname: QualifiedNameQualified name of the function.

args: NormalizedArgTypesNormalized argument types (IN/INOUT/VARIADIC only) used to disambiguate overloads in the DROP FUNCTION statement.
CreateOrReplace(Function)
Replace the function body and/or attributes using CREATE OR REPLACE FUNCTION. Only valid when function_can_or_replace returns true.
ReplaceWithCascade
The function’s return type or language changed in a way that PG’s
CREATE OR REPLACE FUNCTION rejects. The planner must emit
DROP FUNCTION … CASCADE followed by CREATE FUNCTION.
Fields
SetComment
Set (or clear) COMMENT ON FUNCTION.
Fields

qname: QualifiedNameQualified name of the function.

args: NormalizedArgTypesNormalized argument types for disambiguation.